@@ -34,13 +34,16 @@ from typing import (
 )
 from xml.etree import ElementTree
 
-_VERSION_PATTERN = r"""
+VERSION_SOURCE_PATTERN = r"""
     (?x)                                                        (?# ignore whitespace)
     ^v((?P<epoch>\d+)!)?(?P<base>\d+(\.\d+)*)                   (?# v1.2.3 or v1!2000.1.2)
     ([-._]?((?P<stage>[a-zA-Z]+)[-._]?(?P<revision>\d+)?))?     (?# b0)
     (\+(?P<tagged_metadata>.+))?$                               (?# +linux)
 """.strip()
 
+# Preserve old/private name for now in case it exists in the wild
+_VERSION_PATTERN = VERSION_SOURCE_PATTERN
+
 _VALID_PEP440 = r"""
     (?x)
     ^(\d+!)?
@@ -80,9 +83,9 @@ class Vcs(Enum):
 def _run_cmd(
     command: str,
     codes: Sequence[int] = (0,),
-    where: Path = None,
+    where: Optional[Path] = None,
     shell: bool = False,
-    env: dict = None,
+    env: Optional[dict] = None,
 ) -> Tuple[int, str]:
     result = subprocess.run(
         shlex.split(command),
@@ -192,7 +195,7 @@ def _equal_if_set(x: _T, y: Optional[_T], unset: Sequence[Any] = (None,)) -> boo
     return x == y
 
 
-def _detect_vcs(expected_vcs: Vcs = None) -> Vcs:
+def _detect_vcs(expected_vcs: Optional[Vcs] = None) -> Vcs:
     checks = OrderedDict(
         [
             (Vcs.Git, "git status"),
@@ -324,14 +327,14 @@ class Version:
         self,
         base: str,
         *,
-        stage: Tuple[str, Optional[int]] = None,
+        stage: Optional[Tuple[str, Optional[int]]] = None,
         distance: int = 0,
-        commit: str = None,
-        dirty: bool = None,
+        commit: Optional[str] = None,
+        dirty: Optional[bool] = None,
         tagged_metadata: Optional[str] = None,
-        epoch: int = None,
-        branch: str = None,
-        timestamp: dt.datetime = None
+        epoch: Optional[int] = None,
+        branch: Optional[str] = None,
+        timestamp: Optional[dt.datetime] = None
     ) -> None:
         """
         :param base: Release segment, such as 0.1.0.
@@ -457,10 +460,10 @@ class Version:
 
     def serialize(
         self,
-        metadata: bool = None,
+        metadata: Optional[bool] = None,
         dirty: bool = False,
-        format: Union[str, Callable[["Version"], str]] = None,
-        style: Style = None,
+        format: Optional[Union[str, Callable[["Version"], str]]] = None,
+        style: Optional[Style] = None,
         bump: bool = False,
         tagged_metadata: bool = False,
     ) -> str:
@@ -597,7 +600,7 @@ class Version:
         return out
 
     @classmethod
-    def parse(cls, version: str, pattern: str = _VERSION_PATTERN) -> "Version":
+    def parse(cls, version: str, pattern: str = VERSION_SOURCE_PATTERN) -> "Version":
         """
         Attempt to parse a string into a Version instance.
 
@@ -694,7 +697,7 @@ class Version:
         return bumped
 
     @classmethod
-    def from_git(cls, pattern: str = _VERSION_PATTERN, latest_tag: bool = False) -> "Version":
+    def from_git(cls, pattern: str = VERSION_SOURCE_PATTERN, latest_tag: bool = False) -> "Version":
         r"""
         Determine a version based on Git tags.
 
@@ -783,7 +786,9 @@ class Version:
         return version
 
     @classmethod
-    def from_mercurial(cls, pattern: str = _VERSION_PATTERN, latest_tag: bool = False) -> "Version":
+    def from_mercurial(
+        cls, pattern: str = VERSION_SOURCE_PATTERN, latest_tag: bool = False
+    ) -> "Version":
         r"""
         Determine a version based on Mercurial tags.
 
@@ -851,7 +856,9 @@ class Version:
         return version
 
     @classmethod
-    def from_darcs(cls, pattern: str = _VERSION_PATTERN, latest_tag: bool = False) -> "Version":
+    def from_darcs(
+        cls, pattern: str = VERSION_SOURCE_PATTERN, latest_tag: bool = False
+    ) -> "Version":
         r"""
         Determine a version based on Darcs tags.
 
@@ -908,7 +915,7 @@ class Version:
 
     @classmethod
     def from_subversion(
-        cls, pattern: str = _VERSION_PATTERN, latest_tag: bool = False, tag_dir: str = "tags"
+        cls, pattern: str = VERSION_SOURCE_PATTERN, latest_tag: bool = False, tag_dir: str = "tags"
     ) -> "Version":
         r"""
         Determine a version based on Subversion tags.
@@ -985,7 +992,9 @@ class Version:
         return version
 
     @classmethod
-    def from_bazaar(cls, pattern: str = _VERSION_PATTERN, latest_tag: bool = False) -> "Version":
+    def from_bazaar(
+        cls, pattern: str = VERSION_SOURCE_PATTERN, latest_tag: bool = False
+    ) -> "Version":
         r"""
         Determine a version based on Bazaar tags.
 
@@ -1059,7 +1068,9 @@ class Version:
         return version
 
     @classmethod
-    def from_fossil(cls, pattern: str = _VERSION_PATTERN, latest_tag: bool = False) -> "Version":
+    def from_fossil(
+        cls, pattern: str = VERSION_SOURCE_PATTERN, latest_tag: bool = False
+    ) -> "Version":
         r"""
         Determine a version based on Fossil tags.
 
@@ -1162,7 +1173,7 @@ class Version:
 
     @classmethod
     def from_any_vcs(
-        cls, pattern: str = _VERSION_PATTERN, latest_tag: bool = False, tag_dir: str = "tags"
+        cls, pattern: str = VERSION_SOURCE_PATTERN, latest_tag: bool = False, tag_dir: str = "tags"
     ) -> "Version":
         r"""
         Determine a version based on a detected version control system.
@@ -1188,7 +1199,7 @@ class Version:
     def from_vcs(
         cls,
         vcs: Vcs,
-        pattern: str = _VERSION_PATTERN,
+        pattern: str = VERSION_SOURCE_PATTERN,
         latest_tag: bool = False,
         tag_dir: str = "tags",
     ) -> "Version":
@@ -1249,10 +1260,10 @@ def check_version(version: str, style: Style = Style.Pep440) -> None:
 
 def get_version(
     name: str,
-    first_choice: Callable[[], Optional[Version]] = None,
-    third_choice: Callable[[], Optional[Version]] = None,
+    first_choice: Optional[Callable[[], Optional[Version]]] = None,
+    third_choice: Optional[Callable[[], Optional[Version]]] = None,
     fallback: Version = Version("0.0.0"),
-    ignore: Sequence[Version] = None,
+    ignore: Optional[Sequence[Version]] = None,
     parser: Callable[[str], Version] = Version,
 ) -> Version:
     """
@@ -1303,12 +1314,12 @@ def get_version(
 
 def serialize_pep440(
     base: str,
-    stage: str = None,
-    revision: int = None,
-    post: int = None,
-    dev: int = None,
-    epoch: int = None,
-    metadata: Sequence[Union[str, int]] = None,
+    stage: Optional[str] = None,
+    revision: Optional[int] = None,
+    post: Optional[int] = None,
+    dev: Optional[int] = None,
+    epoch: Optional[int] = None,
+    metadata: Optional[Sequence[Union[str, int]]] = None,
 ) -> str:
     """
     Serialize a version based on PEP 440.
@@ -1362,7 +1373,9 @@ def serialize_pep440(
 
 
 def serialize_semver(
-    base: str, pre: Sequence[Union[str, int]] = None, metadata: Sequence[Union[str, int]] = None
+    base: str,
+    pre: Optional[Sequence[Union[str, int]]] = None,
+    metadata: Optional[Sequence[Union[str, int]]] = None,
 ) -> str:
     """
     Serialize a version based on Semantic Versioning.
@@ -1387,7 +1400,7 @@ def serialize_semver(
     return serialized
 
 
-def serialize_pvp(base: str, metadata: Sequence[Union[str, int]] = None) -> str:
+def serialize_pvp(base: str, metadata: Optional[Sequence[Union[str, int]]] = None) -> str:
     """
     Serialize a version based on the Haskell Package Versioning Policy.
     Use this instead of `Version.serialize()` if you want more control
